package com.ruoyi.project.religion.place.mapper;

import java.util.List;
import com.ruoyi.project.religion.place.domain.ReligionPlace;

/**
 * 宗教活动场所Mapper接口
 * 
 * @author ruoyi
 */
public interface ReligionPlaceMapper 
{
    /**
     * 查询宗教活动场所列表
     * 
     * @param place 宗教活动场所
     * @return 宗教活动场所集合
     */
    public List<ReligionPlace> selectPlaceList(ReligionPlace place);

    /**
     * 根据场所ID查询宗教活动场所
     * 
     * @param placeId 场所ID
     * @return 宗教活动场所
     */
    public ReligionPlace selectPlaceById(Long placeId);

    /**
     * 新增宗教活动场所
     * 
     * @param place 宗教活动场所
     * @return 结果
     */
    public int insertPlace(ReligionPlace place);

    /**
     * 修改宗教活动场所
     * 
     * @param place 宗教活动场所
     * @return 结果
     */
    public int updatePlace(ReligionPlace place);

    /**
     * 删除宗教活动场所
     * 
     * @param placeId 场所ID
     * @return 结果
     */
    public int deletePlaceById(Long placeId);

    /**
     * 批量删除宗教活动场所
     * 
     * @param placeIds 需要删除的场所ID
     * @return 结果
     */
    public int deletePlaceByIds(Long[] placeIds);
}


